==> fop2-2.28-centos-x86_64.tgz: fop2/html/js/lang_it.js <==

lang['incoming_call']      = 'Chiamata entrante';
lang['connecting_server']  = 'Connessione al server, tentativo numero ';

lang['from_queue']         = "Dalla Coda:";
lang['number']             = "Numero:";
lang['name']               = "Nome:";

lang['dial']               = 'Componi';
lang['transfer_vmail']     = 'Trasferisci alla Casella Vocale';
lang['attendant_transfer'] = 'Trasferisci';
lang['blind_transfer']     = 'Trasferimento cieco';
lang['transfer_external']  = 'Trasferimento a mobile';
lang['spy']                = 'Ascolta';
lang['whisper']            = 'Ascolta e Suggerisci';
lang['pickup']             = "Prendi la Telefonata";
lang['hangup']             = 'Riaggancia';
lang['filter']             = 'Filtra';

lang['enter_sec_code']     = 'Informazioni di Login';
lang['exten']              = 'Interno:';
lang['password']           = 'Password:';

lang['confirm_hangup']     = 'Conferma Riaggancio';
lang['areyousure']         = 'Sei Sicuro?';
lang['yes']                = 'Si';
lang['no']                 = 'No';
lang['cancel']             = 'Annulla';
lang['accept']             = 'Accettare';

lang['paused']             = 'In Pausa';
lang['set_information']    = 'Imposta le Informazioni';
lang['set_penalty']        = 'Pena';
lang['member_of']          = 'Membro di ';
lang['not_available']      = 'Sistema non disponibile al momento';
lang['not_connect']        = 'Impossibile connettersi al server';
lang['one_moment']         = 'Un momento per favore';
lang['no_results']         = 'Nessun risultato trovato';

lang['toggle_lock']        = 'Blocca/Sblocca Conferenza';
lang['toggle_muteall']     = 'Mute/Unmute tutti gli utenti';
lang['available']          = 'Disponibile';
lang['phonebook']          = 'Rubrica telefonica';
lang['toggle_mute']        = 'Attiva/disattiva microfono';
lang['kick']               = "Espelli l'utente";
lang['record']             = 'Registra la chiamata';
lang['presence_noti']      = 'Notifica Presenza';

lang['queues']             = 'Code';
lang['extensions']         = 'Interni';
lang['trunks']             = 'Linee esterne';
lang['conferences']        = 'Conferenze';
lang['other']              = 'Altro';
lang['enter_state']        = 'Inserisci il valore';
lang['parkingslots']       = 'Parco Slots';
lang['ringgroups']         = 'Gruppi di Chiamata';

lang['enter_reg_code']     = 'Inserisci il codice di registrazione:';
lang['reg_code']           = 'Codice di registrazione:';
lang['reg_name']           = 'Nome di registrazione:';

lang['remove_member']      = 'Rimuovere membri';
lang['remove_member_from'] = 'Togliere dal ';
lang['pause_member']       = 'Pausa membro';
lang['unpause_member']     = 'Riattiva membro';
lang['add_member']         = 'Aggiungi ai ';
lang['pickup_call']        = 'Cattura chiamata';
lang['email_user']         = 'Invia email';
lang['send_sms']           = 'Inviare SMS';
lang['message']            = 'Messaggio:';
lang['sending']            = 'Invio...';
lang['noResponse']         = 'Nessuna risposta.';
lang['calls_taken']        = 'Chiama preso:';
lang['penalty']            = 'Pena';

lang['chat']               = 'Chat';
lang['notlogged']          = 'Utente non collegato. Messaggio salvato.';
lang['me']                 = 'Io';
lang['clearchat']          = 'Pulisci la finestra di chat';
lang['note']               = 'Messaggio';
lang['toggle_sound']       = 'Attiva/disattiva suoni';
lang['says']               = 'dice';

lang['agents']             = 'Agenti: %d';
lang['calls']              = 'Utente in attesa: %d';
lang['call_connected']     = 'Parlando con';
lang['changeDisplayType']  = 'Cambia visualizzazione';

lang['voicemail']          = 'Casella vocale';
lang['vmail_new']          = 'Nuovi';
lang['vmail_old']          = 'Vecchi';
lang['vmail_work']         = 'Lavoro';
lang['vmail_family']       = 'Famiglia';
lang['vmail_friends']      = 'Amici';
lang['vmail_number']       = 'Numero';
lang['vmail_date']         = 'Data';
lang['vmail_callerid']     = 'CallerID';
lang['vmail_duration']     = 'Durata';
lang['play']               = 'Riprodursi';
lang['download']           = 'Caricare';

lang['preferences']        = 'Preferenze';
lang['summary']            = 'Riassunto';
lang['detailed']           = 'Dettagliato';

lang['inactive_line']      = 'Linea %d inattiva';
lang['inuse']              = '%d linee in uso';
lang['vmail_count']        = 'Nuovi %d, Vecchi %d';
lang['logout']             = 'Logout'

lang['NOTONLINE']          = 'Utente non è collegato';
lang['NOWONLINE']          = 'Utente è ora online';

lang['prefSounds']         = 'Suoni di avviso';
lang['prefDisplay']        = 'Visualizzazione';

lang['labelSoundChat']     = 'Suoni della chat';
lang['labelSoundQueue']    = 'Suoni delle code';
lang['labelSoundRing']     = 'Avviso chiamate entranti';

lang['labelDisplayQueue']          = 'Visualizzazione della coda';
lang['labelDisplayDynamicLine']    = 'Visualizzazione dinamica interni';
lang['labelDisplayNotifyDuration'] = 'Notifica della durata';
lang['labelDisplayLanguage']       = 'Lingua';
lang['labelAutoPopup']             = 'Auto Popup';

lang['close']                      = 'Chiudere';
lang['recordings']                 = 'Registrazioni';
lang['cdrrecords']                 = 'Chiamiamo Storia';

// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
		"Dom", "Lun", "Mar", "Mer", "Gio", "Ven", "Sab",
        "Domenica", "Lunedì", "Martedì", "Mercoledì", "Giovedì", "Venerdì", "Sabato"
	],
	monthNames: [
        "Gen","Feb","Mar","Apr","Mag","Giu","Lug","Ago","Set","Ott","Nov","Dic", 
        "Gennaio","Febbraio","Marzo","Aprile","Maggio","Giugno","Luglio","Agosto","Settembre","Ottobre","Novembre","Dicembre"
	]
};

==> fop2-2.31.29-centos-x86_64.tgz: fop2/html/js/lang_it.js <==
// Italian

lang['incoming_call']      = 'Chiamata entrante';
lang['connecting_server']  = 'Connessione al server, tentativo numero ';

lang['from_queue']         = "Dalla Coda:";
lang['number']             = "Numero:";
lang['name']               = "Nome:";

lang['dial']               = 'Componi';
lang['transfer_vmail']     = 'Trasferisci alla Casella Vocale';
lang['attendant_transfer'] = 'Trasferisci';
lang['blind_transfer']     = 'Trasferimento cieco';
lang['transfer_external']  = 'Trasferimento a mobile';
lang['spy']                = 'Ascolta';
lang['whisper']            = 'Ascolta e Suggerisci';
lang['pickup']             = "Prendi la Telefonata";
lang['hangup']             = 'Riaggancia';
lang['filter']             = 'Filtra';
lang['reset']              = 'Reimpostare';

lang['enter_sec_code']     = 'Informazioni di Login';
lang['exten']              = 'Interno:';
lang['password']           = 'Password:';

lang['confirm_hangup']     = 'Conferma Riaggancio';
lang['areyousure']         = 'Sei Sicuro?';
lang['yes']                = 'Si';
lang['no']                 = 'No';
lang['cancel']             = 'Annulla';
lang['accept']             = 'Accettare';

lang['paused']             = 'In Pausa';
lang['reason']             = 'Motivo';
lang['broadcast']          = 'Trasmissione';
lang['set_information']    = 'Imposta le Informazioni';
lang['set_penalty']        = 'Pena';
lang['member_of']          = 'Membro di ';
lang['not_available']      = 'Sistema non disponibile al momento';
lang['not_connect']        = 'Impossibile connettersi al server';
lang['one_moment']         = 'Un momento per favore';
lang['no_results']         = 'Nessun risultato trovato';

lang['toggle_lock']        = 'Blocca/Sblocca';
lang['toggle_muteall']     = 'Mute/Unmute tutti gli utenti';
lang['phonebook']          = 'Rubrica telefonica';
lang['contacts']           = 'Contatti';
lang['toggle_mute']        = 'Attiva/disattiva microfono';
lang['kick']               = "Espelli l'utente";
lang['record']             = 'Registra la chiamata';
lang['presence_noti']      = 'Notifica Presenza';

lang['available']          = 'Disponibile';
lang['Do not Disturb']     = 'Non Disturbare';
lang['Out to lunch']       = 'Pranzo';
lang['Break']              = 'Intervallo';
lang['Meeting']            = 'Riunione';
lang['other']              = 'Altro';

lang['queues']             = 'Code';
lang['extensions']         = 'Interni';
lang['trunks']             = 'Linee esterne';
lang['conferences']        = 'Conferenze';
lang['enter_state']        = 'Inserisci il valore';
lang['parkingslots']       = 'Parco Slots';
lang['ringgroups']         = 'Gruppi di Chiamata';

lang['enter_reg_code']     = 'Inserisci il codice di registrazione:';
lang['reg_code']           = 'Codice di registrazione:';
lang['reg_name']           = 'Nome di registrazione:';

lang['remove_member']      = 'Rimuovere membri';
lang['remove_member_from'] = 'Togliere dal ';
lang['pause_member']       = 'Pausa membro';
lang['unpause_member']     = 'Riattiva membro';
lang['add_member']         = 'Aggiungi ai ';
lang['pickup_call']        = 'Cattura chiamata';
lang['email_user']         = 'Invia email';
lang['send_sms']           = 'Inviare SMS';
lang['send']               = 'Inviare';
lang['message']            = 'Messaggio:';
lang['sending']            = 'Invio...';
lang['noResponse']         = 'Nessuna risposta.';
lang['calls_taken']        = 'Chiama preso:';
lang['penalty']            = 'Pena';

lang['chat']               = 'Chat';
lang['notlogged']          = 'Utente non collegato. Messaggio salvato.';
lang['me']                 = 'Io';
lang['clearchat']          = 'Pulisci la finestra di chat';
lang['note']               = 'Messaggio';
lang['toggle_sound']       = 'Attiva/disattiva suoni';
lang['says']               = 'dice';

lang['agents']             = 'Agenti: %d';
lang['calls']              = 'Utente in attesa: %d';
lang['call_connected']     = 'Parlando con';
lang['call_ended']         = 'Chiamata terminata
lang['changeDisplayType']  = 'Cambia visualizzazione';

lang['voicemail']          = 'Casella vocale';
lang['vmail_new']          = 'Nuovi';
lang['vmail_old']          = 'Vecchi';
lang['vmail_work']         = 'Lavoro';
lang['vmail_family']       = 'Famiglia';
lang['vmail_friends']      = 'Amici';
lang['vmail_number']       = 'Numero';
lang['vmail_date']         = 'Data';
lang['vmail_callerid']     = 'CallerID';
lang['vmail_duration']     = 'Durata';
lang['play']               = 'Riprodursi';
lang['download']           = 'Caricare';

lang['preferences']        = 'Preferenze';
lang['summary']            = 'Riassunto';
lang['detailed']           = 'Dettagliato';

lang['inactive_line']      = 'Linea %d inattiva';
lang['inuse']              = '%d linee in uso';
lang['vmail_count']        = 'Nuovi %d, Vecchi %d';
lang['logout']             = 'Logout'

lang['NOTONLINE']          = 'Utente non è collegato';
lang['NOWONLINE']          = 'Utente è ora online';

lang['prefSounds']         = 'Suoni di avviso';
lang['prefDisplay']        = 'Visualizzazione';
lang['prefPopup']          = 'Popup';
lang['prefPhone']          = 'Telefono';

lang['labelSoundChat']     = 'Suoni della chat';
lang['labelSoundQueue']    = 'Suoni delle code';
lang['labelSoundRing']     = 'Avviso chiamate entranti';
lang['labelAlwaysNotifyChat']     = 'Always Notify Chat';

lang['labelDisplayQueue']          = 'Visualizzazione della coda';
lang['labelDisplayDynamicLine']    = 'Visualizzazione dinamica interni';
lang['labelDisplayNotifyDuration'] = 'Notifica della durata';
lang['labelDisplayLanguage']       = 'Lingua';
lang['labelAutoPopup']             = 'Auto Popup';
lang['labelAutoAnswer']            = 'Risposta Automatica';
lang['labelNotification']          = 'Notifica';

lang['close']                      = 'Chiudere';
lang['recordings']                 = 'Registrazioni';
lang['cdrrecords']                 = 'Storico Chiamate';
lang['chathistory']                = 'Chat history';

lang['invalid_credentials']        = 'Credenziali non valide';
lang['collapse']                   = 'Crollo';

// Internationalization strings DATE
dateFormat.i18n = {
	dayNames: [
		"Dom", "Lun", "Mar", "Mer", "Gio", "Ven", "Sab",
        "Domenica", "Lunedì", "Martedì", "Mercoledì", "Giovedì", "Venerdì", "Sabato"
	],
	monthNames: [
        "Gen","Feb","Mar","Apr","Mag","Giu","Lug","Ago","Set","Ott","Nov","Dic", 
        "Gennaio","Febbraio","Marzo","Aprile","Maggio","Giugno","Luglio","Agosto","Settembre","Ottobre","Novembre","Dicembre"
	]
};

jQuery.timeago.settings.strings = {
  suffixAgo: "fa",
  suffixFromNow: "da ora",
  seconds: "meno di un minuto",
  minute: "circa un minuto",
  minutes: "%d minuti",
  hour: "circa un'ora",
  hours: "circa %d ore",
  day: "un giorno",
  days: "%d giorni",
  month: "circa un mese",
  months: "%d mesi",
  year: "circa un anno",
  years: "%d anni"
};
